cheesecake.model.ImportStarFinder

Package cheesecake :: Module model :: Class ImportStarFinder |
[hide private]
[frames] | no frames]

## Class ImportStarFinder
source code

    object --+
             |
            ImportStarFinder

Instance Methods | [hide private]
| __init__(self, system, modfullname) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
| visitFrom(self, node)
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, system, modfullname) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### visitFrom(self, node) | source code